Module http

Module http 

Re-exports

pub use field::Field;
pub use field::OwnedField;
pub use huffman::HpackHuffman;
pub use huffman::HpackHuffmanError;
pub use varint::VarInt;

Modules

body_kind
codec
compress
field
head
huffman
scan
Safe byte-scanning primitives for HTTP syntax.
varint

Structs

Borrowed
A non-owning byte slice valid for 'a.
Bytes
Bytes with a statically selected storage policy and no wrapper overhead.
Chunked
EncodedResponse
FixedResponse
HeadInner
HeaderItem
HeaderList
HeaderNameToken
HeaderStaticValueToken
Headers
InlineHeaderValue
IterStream
Method
The Request Method (VERB)
MonoResponseInner
PathParamRanges
Response
ResponsePlan
ResponseView
Retained
Bytes retained beyond their callback through pooled or shared ownership.
StaticResponseInner
A response whose body is guaranteed to live for the entire process.
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).
Stream
TextBody

Enums

Body
CacheTemplate
Egress
HeaderValueInner
HotBodyInner
HotHeadInner
NeverStream
Preparation
Prepared
Serve
TextItem

Constants

CHUNK_TERMINATOR
DEFAULT_HEADER_CAPACITY

Traits

EncodedBody
HeaderNameRef
OwnedShape
Shape