Bytes

Struct Bytes 

pub struct Bytes<S> { /* private fields */ }
Bytes with a statically selected storage policy and no wrapper overhead.

Implementations

Source

impl<'a> Bytes<Borrowed<'a>>

pub fn slice(self, range: Range<usize>) -> Bytes<Borrowed<'a>>

Panics

Panics if range is reversed or out of bounds.

Source

impl Bytes<Shared>

pub fn into_shared(self) -> Shared

pub fn slice(self, range: Range<usize>) -> Bytes<Shared>

Panics

Panics if range is reversed or out of bounds.

Source

impl Bytes<Retained>

pub fn copy_from_slice(slice: &[u8]) -> Bytes<Retained>

pub fn into_shared(self) -> Shared

pub fn slice(self, range: Range<usize>) -> Bytes<Retained>

Panics

Panics if range is reversed or out of bounds.

pub fn advance(&mut self, n: usize)

Panics

Panics if n exceeds the remaining length.

Source

impl<S> Bytes<S>
where S: Storage,

pub fn as_slice(&self) -> &[u8]

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

Source

impl<S> Bytes<S>
where Bytes<S>: RetainBytes,