pub struct StaticResponseInner<'req, const N: usize = DEFAULT_HEADER_CAPACITY> { /* private fields */ }Expand description
A response whose body is guaranteed to live for the entire process.
Keeping the static slice directly avoids paying for the largest variant of
HotBodyInner on generated static-response routes.
Implementations
Sourceimpl<'req, const N: usize> StaticResponseInner<'req, N>
impl<'req, const N: usize> StaticResponseInner<'req, N>
pub fn direct( status: StatusCode, static_headers: &'static [u8], headers: Headers<'req, N>, body: &'static [u8], ) -> Self
pub fn status(&self) -> StatusCode
pub fn body_ref(&self) -> &'static [u8] ⓘ
pub fn wire_headers(&self) -> Shared
pub fn write_into_slice(&self, out: &mut [u8], date: &[u8; 29]) -> Option<usize>
pub fn write_head_only( &self, out: &mut [u8], date: &[u8; 29], ) -> Option<(usize, &'static [u8])>
pub fn write_head_split( self, out: &mut [u8], date: &[u8; 29], ) -> Option<(usize, Shared)>
pub fn preserialize_static(&self) -> (Vec<u8>, usize, &'static [u8])