Re-exports
pub use field::Field;pub use field::OwnedField;pub use huffman::HpackHuffman;pub use huffman::HpackHuffmanError;pub use varint::VarInt;
Modules
Structs
- Borrowed
- A non-owning byte slice valid for
'a. - Bytes
- Bytes with a statically selected storage policy and no wrapper overhead.
- Chunked
- Encoded
Response - Fixed
Response - Head
Inner - Header
Item - Header
List - Header
Name Token - Header
Static Value Token - Headers
- Inline
Header Value - Iter
Stream - Method
- The Request Method (VERB)
- Mono
Response Inner - Path
Param Ranges - Response
- Response
Plan - Response
View - Retained
- Bytes retained beyond their callback through pooled or shared ownership.
- Static
Response Inner - A response whose body is guaranteed to live for the entire process.
- Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - Stream
- Text
Body
Enums
- Body
- Cache
Template - Egress
- Header
Value Inner - HotBody
Inner - HotHead
Inner - Never
Stream - Preparation
- Prepared
- Serve
- Text
Item