Re-exports
pub use field::Field;pub use field::OwnedField;pub use huffman::HpackHuffman;pub use huffman::HpackHuffmanError;pub use varint::VarInt;
Modules
Structs
- Borrowed
- A non-owning byte slice valid for
'a. - Bytes
- Bytes with a statically selected storage policy and no wrapper overhead.
- Chunked
- Encoded
Response Inner - Fixed
Response Inner - Head
Inner - Header
Item Inner - Header
List - Header
Name Token - Header
Static Value Token - Headers
Inner - HotText
Inner - Inline
Header Value - Iter
Stream - Method
- The Request Method (VERB)
- Mono
Response Inner - Never
Stream - Path
Param Ranges - Response
- Response
Plan Inner - Retained
- Bytes retained beyond their callback through pooled or shared ownership.
- Static
Response Inner - A response whose body is guaranteed to live for the entire process.
- Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - Stream
Enums
Constants
Traits
- Encoded
Body - Header
Name Ref - Into
Body - Into
Header Name - Into
Header Value - Into
Serve Response - Owned
Shape - Shape
- Text
Spec